@@ -13,6 +13,7 @@ const (
 	Javascript = "javascript"
 	Python     = "python"
 	Ruby       = "ruby"
+	Perl       = "perl"
 )
 
 var Languages = map[string]Language{
@@ -40,4 +41,8 @@ var Languages = map[string]Language{
 		Extension: "py",
 		Command:   []string{"python"},
 	},
+	Perl: {
+		Extension: "pl",
+		Command:   []string{"perl"},
+	},
 }
